#
# spec file for package thunarx-python
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           thunarx-python
Version:        0.5.2
Release:        1.21
Summary:        Python Bindings for the Thunar Extension Framework
License:        GPL-2.0-or-later
URL:            https://docs.xfce.org/bindings/thunarx-python/
Source:         http://archive.xfce.org/src/bindings/%{name}/0.5/%{name}-%{version}.tar.bz2
BuildRequires:  fdupes
BuildRequires:  gtk-doc
BuildRequires:  pkgconfig
BuildRequires:  python3-devel
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.20.0
BuildRequires:  pkgconfig(pygobject-3.0) >= 3.20.0
BuildRequires:  pkgconfig(thunarx-3)
Requires:       thunar
Recommends:     %{name}-doc = %{version}

%description
This package provides the Python bindings for the Thunar Extension framework
which allow one to create Python plugins for Thunar.

%package doc
Summary:        Documentation for thunarx-python

%description doc
This package provides the documentation files for python thunarx.

%prep
%autosetup -p1

%build
# gcc10 workaround
export CFLAGS="%{optflags} -fcommon"
%configure \
    --enable-gtk-doc \
    --docdir=%{_defaultdocdir}/%{name}
%make_build

%install
%make_install
mv %{buildroot}%{_defaultdocdir}/%{name}/README \
    %{buildroot}%{_defaultdocdir}/%{name}/README.examples
rm -f %{buildroot}%{_libdir}/thunarx-python/thunarx.la \
    %{buildroot}%{_libdir}/thunarx-3/thunarx-python.la

%files
%dir %{_libdir}/thunarx-3/
%{_libdir}/thunarx-3/thunarx-python.so

%files doc
%doc %{_defaultdocdir}/%{name}
%doc %{_datadir}/gtk-doc/html/thunarx-python/

%changelog
* Sun Jan 31 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.5.2
  * Add gitlab-ci for thunarx-python
  * Update configure.ac.in syntax
  * Remove checks with unused result
  * Remove check for unused sys/wait.h
  * Fix missing-prototypes
  * Fix g_list_find_custom usage
  * make distcheck now works !
  * Update gtk-doc for thunarx-python
  * Fix compilation with python3.8
  * fix compilation issues with gcc-10
  * Scan extension directories only once
- Remove reproducible.patch and thunarx-python-py3.8.diff
  * fixed upstream
* Mon Jun  8 2020 Stefan Seyfried <seife+obs@b1-systems.com>
- add -fcommon to CFLAGS to work around gcc10 default changes
* Tue Mar 17 2020 Stefan Seyfried <seife+obs@b1-systems.com>
- add thunarx-python-py3.8.diff to add missing "--embed" flag to
  python3-config
* Mon Feb 24 2020 Stefan Seyfried <seife+obs@b1-systems.com>
- port reproducible.patch to python 3
* Mon Feb 10 2020 Tomáš Chvátal <tchvatal@suse.com>
- Do not pull in python-gtk as that is py2 only and this package
  now uses introspection and gtk3
* Wed Jan 15 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Build against python 3
* Mon Jun 10 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to override build date
  to make package build reproducible (boo#1047218)
* Fri Jun 15 2018 seife+obs@b1-systems.com
- update to version 0.5.1:
  - Fix building docs with python3 (bxo#14199)
  - Updated to work with python3 or python2
  - Improve extension path loading semantics to follow XDG
    recommendations
  - Updated to work with Thunarx-3 which requires uses gobject
    introspection and requires Gtk+3 and PyGObject3
* Sat Feb 17 2018 seife+obs@b1-systems.com
- disable gnome-python BuildRequires (boo#1081189)
- ran spec-cleaner (but did not implement the braindead stuff)
  - remove %%py_requires
* Fri Jul 14 2017 mailaender@opensuse.org
- SPDX.org compliant license
* Tue Apr 17 2012 gber@opensuse.org
- fix source URL
* Fri Oct 14 2011 gber@opensuse.org
- recommend -doc subpackage
* Fri Apr  1 2011 gber@opensuse.org
- update to version 0.3.0:
  - look for python extensions in
    $XDG_DATA_DIR/thunarx-python/extensions rather than
    /usr/lib/thunarx-1/python.
  - fix PyCapsule support for the pygobject module
  - don't hard-code the docs directory in the Makefile.am files
  - use g_return_val_if_fail in override function instead of
    g_return_if_fail
  - updated documentation and moved examples to its own folder
  - removed the dependency on gnome-python2, there was no need for
    it
- dropped obsolete thunarx-python-0.2.3-honor-docdir.patch and
  thunarx-python-0.2.3-return-value-from-nonvoid-func.patch
* Thu Mar 24 2011 gber@opensuse.org
- new package
